@@ -15,31 +15,33 @@ placeholder will always include enough entries for every zone in the arena,
 using '-' to represent an empty zone.
 """
 
+from __future__ import annotations
+
 import argparse
 import sys
-from typing import Callable, Dict, List, TYPE_CHECKING
+from typing import Callable, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from sr.comp.match_period import Match
 
 
-def get_tlas(match: 'Match') -> List[str]:
+def get_tlas(match: Match) -> list[str]:
     return [
         x if x is not None else '-'
         for x in match.teams
     ]
 
 
-PLACEHOLDERS = {
+PLACEHOLDERS: dict[str, Callable[[Match], list[str]]] = {
     'ARENA': lambda x: [x.arena],
     'NUMBER': lambda x: [str(x.num)],
     'TLAS': get_tlas,
     'TYPE': lambda x: [str(x.type.value)],
-}  # type: Dict[str, Callable[[Match], List[str]]]
+}
 
 
 class PlaceholderExpander:
-    def __init__(self, match: 'Match') -> None:
+    def __init__(self, match: Match) -> None:
         self.match = match
 
     @staticmethod
@@ -50,7 +52,7 @@ class PlaceholderExpander:
     def __getitem__(self, key: str) -> str:
         return ' '.join(PLACEHOLDERS[key](self.match))
 
-    def expand(self, value: str) -> List[str]:
+    def expand(self, value: str) -> list[str]:
         if value.startswith('@'):
             key = value[1:]
             fn = PLACEHOLDERS.get(key)
@@ -60,7 +62,7 @@ class PlaceholderExpander:
         return [value.format_map(self)]
 
 
-def replace_placeholders(match: 'Match', command: List[str]) -> List[str]:
+def replace_placeholders(match: Match, command: list[str]) -> list[str]:
     import itertools
 
     expander = PlaceholderExpander(match)
@@ -70,7 +72,7 @@ def replace_placeholders(match: 'Match', command: List[str]) -> List[str]:
     ))
 
 
-def command(args):
+def command(args: argparse.Namespace) -> None:
     import subprocess
 
     from sr.comp.comp import SRComp
@@ -103,7 +105,7 @@ def command(args):
         exit(1)
 
 
-def add_options(parser):
+def add_options(parser: argparse.ArgumentParser) -> None:
     from sr.comp.matches import parse_ranges
 
     parser.add_argument(
@@ -134,7 +136,7 @@ def add_options(parser):
     )
 
 
-def add_subparser(subparsers):
+def add_subparser(subparsers: argparse._SubParsersAction[argparse.ArgumentParser]) -> None:
     parser = subparsers.add_parser(
         'for-each-match',
         help="Run a command for each of the given matches.",
